pub trait Content: Any {
// Required method
fn to_string(&self, theme: &Theme) -> String;
}Expand description
A value that can be displayed as content in a tree node.
This trait is implemented for all types that can appear as leaf content or labels in a tree. It provides a way to convert a value to a colored string representation.
Required Methods