pub struct Tree {
pub label: Option<Box<dyn Content>>,
pub content: Box<dyn Content>,
pub subtrees: Vec<Tree>,
}Expand description
A tree node containing content and child subtrees.
Trees are built from a root node with zero or more child nodes, each of which can have their own children. Nodes can optionally have labels that appear alongside their content.
Example
use tree_display::{Tree, format::Member};
let tree = Tree::leaf("root")
.labeled(Member::new("label"));Fields
label: Option<Box<dyn Content>>Optional label displayed next to the content
content: Box<dyn Content>The main content of this node
subtrees: Vec<Tree>Child subtrees
Implementations