TreeDisplay

Trait TreeDisplay 

pub trait TreeDisplay {
    // Required method
    fn tree(&self, context: &Context) -> Tree;
}
A type that can be displayed as a tree.

This trait is automatically implemented by #[derive(TreeDisplay)] and is also implemented for many standard library types.

Required Methods

fn tree(&self, context: &Context) -> Tree

Converts the value into a tree structure using the given context.

The context provides custom mappers that can transform values before they are displayed.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl TreeDisplay for &str

&str is displayed as a string leaf, not a tree of characters.

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for ()

Source

fn tree(&self, context: &Context) -> Tree

Source

impl TreeDisplay for Duration

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for Instant

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroI8

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroI16

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroI32

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroI64

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroI128

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroIsize

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroU8

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroU16

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroU32

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroU64

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroU128

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for NonZeroUsize

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for OsStr

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for OsString

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for Path

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for PathBuf

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for RangeFull

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for SimpleSpan

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for String

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for SystemTime

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for bool

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for char

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for f32

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for f64

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for i8

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for i16

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for i32

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for i64

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for i128

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for isize

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for u8

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for u16

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for u32

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for u64

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for u128

Source

fn tree(&self, _: &Context) -> Tree

Source

impl TreeDisplay for usize

Source

fn tree(&self, _: &Context) -> Tree

Source

impl<K: Clone + Content, V: TreeDisplay, S> TreeDisplay for HashMap<K, V, S>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<K: Clone + Content, V: TreeDisplay> TreeDisplay for BTreeMap<K, V>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay, T3: TreeDisplay, T4: TreeDisplay, T5: TreeDisplay, T6: TreeDisplay, T7: TreeDisplay, T8: TreeDisplay, T9: TreeDisplay, T10: TreeDisplay, T11: TreeDisplay> TreeDisplay for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay, T3: TreeDisplay, T4: TreeDisplay, T5: TreeDisplay, T6: TreeDisplay, T7: TreeDisplay, T8: TreeDisplay, T9: TreeDisplay, T10: TreeDisplay> TreeDisplay for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay, T3: TreeDisplay, T4: TreeDisplay, T5: TreeDisplay, T6: TreeDisplay, T7: TreeDisplay, T8: TreeDisplay, T9: TreeDisplay> TreeDisplay for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay, T3: TreeDisplay, T4: TreeDisplay, T5: TreeDisplay, T6: TreeDisplay, T7: TreeDisplay, T8: TreeDisplay> TreeDisplay for (T0, T1, T2, T3, T4, T5, T6, T7, T8)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay, T3: TreeDisplay, T4: TreeDisplay, T5: TreeDisplay, T6: TreeDisplay, T7: TreeDisplay> TreeDisplay for (T0, T1, T2, T3, T4, T5, T6, T7)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay, T3: TreeDisplay, T4: TreeDisplay, T5: TreeDisplay, T6: TreeDisplay> TreeDisplay for (T0, T1, T2, T3, T4, T5, T6)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay, T3: TreeDisplay, T4: TreeDisplay, T5: TreeDisplay> TreeDisplay for (T0, T1, T2, T3, T4, T5)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay, T3: TreeDisplay, T4: TreeDisplay> TreeDisplay for (T0, T1, T2, T3, T4)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay, T3: TreeDisplay> TreeDisplay for (T0, T1, T2, T3)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay, T2: TreeDisplay> TreeDisplay for (T0, T1, T2)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay, T1: TreeDisplay> TreeDisplay for (T0, T1)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T0: TreeDisplay> TreeDisplay for (T0,)

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay + ?Sized> TreeDisplay for &T

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay + ?Sized> TreeDisplay for &mut T

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay + ?Sized> TreeDisplay for Arc<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay + ?Sized> TreeDisplay for Box<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay + ?Sized> TreeDisplay for Rc<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay + Debug + Clone + 'static> TreeDisplay for Range<T>

Source

fn tree(&self, _: &Context) -> Tree

Source

impl<T: TreeDisplay + Debug + Clone + 'static> TreeDisplay for RangeFrom<T>

Source

fn tree(&self, _: &Context) -> Tree

Source

impl<T: TreeDisplay + Debug + Clone + 'static> TreeDisplay for RangeInclusive<T>

Source

fn tree(&self, _: &Context) -> Tree

Source

impl<T: TreeDisplay + Debug + Clone + 'static> TreeDisplay for RangeTo<T>

Source

fn tree(&self, _: &Context) -> Tree

Source

impl<T: TreeDisplay + Debug + Clone + 'static> TreeDisplay for RangeToInclusive<T>

Source

fn tree(&self, _: &Context) -> Tree

Source

impl<T: TreeDisplay, E: TreeDisplay> TreeDisplay for Result<T, E>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay, S> TreeDisplay for HashSet<T, S>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay, const N: usize> TreeDisplay for [T; N]

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for BTreeSet<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for BinaryHeap<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for LinkedList<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for Mutex<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for Option<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for RefCell<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for RwLock<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for Vec<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for VecDeque<T>

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T: TreeDisplay> TreeDisplay for [T]

Source

fn tree(&self, context: &Context) -> Tree

Source

impl<T> TreeDisplay for PhantomData<T>

Source

fn tree(&self, _: &Context) -> Tree

Implementors