pub trait TreeDisplay {
// Required method
fn tree(&self, context: &Context) -> Tree;
}Expand description
A type that can be displayed as a tree.
This trait is automatically implemented by #[derive(TreeDisplay)]
and is also implemented for many standard library types.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl TreeDisplay for &str
&str is displayed as a string leaf, not a tree of characters.
impl TreeDisplay for &str
&str is displayed as a string leaf, not a tree of characters.